@@ -1,6 +1,6 @@
 #define QT_FEATURE_ifr_index -1
 
-#define QT_FEATURE_libproxy -1
+#define QT_FEATURE_libproxy 1
 
 #define QT_FEATURE_linux_netlink 1
 
